@@ -12,3 +12,7 @@ INSTALLED_APPS = (
     'reversetag',
     'revtest',
 )
+
+TEMPLATE_LOADERS = (
+    'django.template.loaders.app_directories.load_template_source',
+)
